@@ -536,7 +536,7 @@ def http_get(
         total=total,
         initial=resume_size,
         desc="Downloading",
-        disable=bool(logging.get_verbosity() == logging.NOTSET),
+        disable=bool(logging.get_verbosity() >= logging.WARNING),
     )
     for chunk in response.iter_content(chunk_size=1024):
         if chunk:  # filter out keep-alive new chunks
@@ -826,3 +826,18 @@ def readline(f: io.RawIOBase):
         if res.endswith(b"\n"):
             break
     return bytes(res)
+
+
+def rmdir(root_path: str) -> None:
+    """Recursively removes a directory."""
+    root = Path(root_path)
+    if not root.exists():
+        return
+
+    for item in root.iterdir():
+        if item.is_dir():
+            rmdir(item)
+        else:
+            item.unlink()
+
+    root.rmdir()
